==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/base/reaction/src/test/java/org/openscience/cdk/reaction/mechanism/RadicalSiteIonizationMechanismTest.java <==
/* Copyright (C) 2008  Miguel Rojas <miguelrojasch@yahoo.es>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.reaction.mechanism;

import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;
import org.openscience.cdk.reaction.IReactionMechanism;
import org.openscience.cdk.reaction.ReactionMechanismTest;

/**
 * Tests for RadicalSiteIonizationMechanism implementations.
 *
 * @cdk.module test-reaction
 */
public class RadicalSiteIonizationMechanismTest extends ReactionMechanismTest {

    /**
     *  The JUnit setup method
     */
    @BeforeClass
    public static void setUp() throws Exception {
        setMechanism(RadicalSiteRearrangementMechanism.class);
    }

    /**
     *  Constructor for the RadicalSiteIonizationMechanismTest object.
     */
    public RadicalSiteIonizationMechanismTest() {
        super();
    }

    /**
     * Junit test.
     *
     * @throws Exception
     */
    @Test
    public void testRadicalSiteIonizationMechanism() {
        IReactionMechanism mechanism = new RadicalSiteIonizationMechanism();
        Assert.assertNotNull(mechanism);
    }

    /**
     * Junit test.
     * TODDO: REACT: add an example
     *
     * @throws Exception
     */
    @Test
    public void testInitiate_IAtomContainerSet_ArrayList_ArrayList() {
        IReactionMechanism mechanism = new RadicalSiteIonizationMechanism();

        Assert.assertNotNull(mechanism);
    }
}

==> cdk_2.11.orig.tar.gz: cdk-cdk-2.11/base/reaction/src/test/java/org/openscience/cdk/reaction/mechanism/RadicalSiteIonizationMechanismTest.java <==
/* Copyright (C) 2008  Miguel Rojas <miguelrojasch@yahoo.es>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.reaction.mechanism;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.openscience.cdk.reaction.IReactionMechanism;
import org.openscience.cdk.reaction.ReactionMechanismTest;

/**
 * Tests for RadicalSiteIonizationMechanism implementations.
 *
 */
class RadicalSiteIonizationMechanismTest extends ReactionMechanismTest {

    /**
     *  The JUnit setup method
     */
    @BeforeAll
    static void setUp() throws Exception {
        setMechanism(RadicalSiteRearrangementMechanism.class);
    }

    /**
     *  Constructor for the RadicalSiteIonizationMechanismTest object.
     */
    RadicalSiteIonizationMechanismTest() {
        super();
    }

    /**
     * Junit test.
     *
     * @throws Exception
     */
    @Test
    void testRadicalSiteIonizationMechanism() {
        IReactionMechanism mechanism = new RadicalSiteIonizationMechanism();
        Assertions.assertNotNull(mechanism);
    }

    /**
     * Junit test.
     * TODDO: REACT: add an example
     *
     * @throws Exception
     */
    @Test
    void testInitiate_IAtomContainerSet_ArrayList_ArrayList() {
        IReactionMechanism mechanism = new RadicalSiteIonizationMechanism();

        Assertions.assertNotNull(mechanism);
    }
}
